@@ -5,7 +5,8 @@
     :copyright: (c) 2014 by Openlabs Technologies & Consulting (P) Limited
     :license: GPLv3, see LICENSE for more details.
 """
-from trytond.pool import PoolMeta
+from trytond.pool import PoolMeta, Pool
+from nereid import abort
 
 __all__ = ['Sale']
 __metaclass__ = PoolMeta
@@ -24,3 +25,15 @@ class Sale:
             'revenue': str(self.total_amount),
             'tax': str(self.tax_amount),
         }
+
+    def _add_or_update(self, product_id, quantity, action='set'):
+        """
+        Raise 400 if someone tries to add gift card to cart using
+        add_to_cart method
+        """
+        Product = Pool().get('product.product')
+
+        if Product(product_id).is_gift_card:
+            abort(400)
+
+        return super(Sale, self)._add_or_update(product_id, quantity, action)
